# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: endpoints/batch_create_artifact_part.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*endpoints/batch_create_artifact_part.proto\x12\tendpoints\"\"\n CreateArtifactPartConfigMetadata\"\xe7\x01\n\x18\x43reateArtifactPartConfig\x12`\n\x18metadatas_by_part_number\x18\x01 \x03(\x0b\x32>.endpoints.CreateArtifactPartConfig.MetadatasByPartNumberEntry\x1ai\n\x1aMetadatasByPartNumberEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12:\n\x05value\x18\x02 \x01(\x0b\x32+.endpoints.CreateArtifactPartConfigMetadata:\x02\x38\x01\"\xe5\x01\n\x1e\x42\x61tchCreateArtifactPartRequest\x12\x62\n\x16\x63onfigs_by_artifact_id\x18\x01 \x03(\x0b\x32\x42.endpoints.BatchCreateArtifactPartRequest.ConfigsByArtifactIdEntry\x1a_\n\x18\x43onfigsByArtifactIdEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.endpoints.CreateArtifactPartConfig:\x02\x38\x01\"X\n CreateArtifactPartResultMetadata\x12\x1e\n\x11upload_signed_url\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x14\n\x12_upload_signed_url\"\xe7\x01\n\x18\x43reateArtifactPartResult\x12`\n\x18metadatas_by_part_number\x18\x01 \x03(\x0b\x32>.endpoints.CreateArtifactPartResult.MetadatasByPartNumberEntry\x1ai\n\x1aMetadatasByPartNumberEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12:\n\x05value\x18\x02 \x01(\x0b\x32+.endpoints.CreateArtifactPartResultMetadata:\x02\x38\x01\"\xe7\x01\n\x1f\x42\x61tchCreateArtifactPartResponse\x12\x63\n\x16results_by_artifact_id\x18\x01 \x03(\x0b\x32\x43.endpoints.BatchCreateArtifactPartResponse.ResultsByArtifactIdEntry\x1a_\n\x18ResultsByArtifactIdEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.endpoints.CreateArtifactPartResult:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'endpoints.batch_create_artifact_part_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CREATEARTIFACTPARTCONFIG_METADATASBYPARTNUMBERENTRY._options = None
  _CREATEARTIFACTPARTCONFIG_METADATASBYPARTNUMBERENTRY._serialized_options = b'8\001'
  _BATCHCREATEARTIFACTPARTREQUEST_CONFIGSBYARTIFACTIDENTRY._options = None
  _BATCHCREATEARTIFACTPARTREQUEST_CONFIGSBYARTIFACTIDENTRY._serialized_options = b'8\001'
  _CREATEARTIFACTPARTRESULT_METADATASBYPARTNUMBERENTRY._options = None
  _CREATEARTIFACTPARTRESULT_METADATASBYPARTNUMBERENTRY._serialized_options = b'8\001'
  _BATCHCREATEARTIFACTPARTRESPONSE_RESULTSBYARTIFACTIDENTRY._options = None
  _BATCHCREATEARTIFACTPARTRESPONSE_RESULTSBYARTIFACTIDENTRY._serialized_options = b'8\001'
  _CREATEARTIFACTPARTCONFIGMETADATA._serialized_start=57
  _CREATEARTIFACTPARTCONFIGMETADATA._serialized_end=91
  _CREATEARTIFACTPARTCONFIG._serialized_start=94
  _CREATEARTIFACTPARTCONFIG._serialized_end=325
  _CREATEARTIFACTPARTCONFIG_METADATASBYPARTNUMBERENTRY._serialized_start=220
  _CREATEARTIFACTPARTCONFIG_METADATASBYPARTNUMBERENTRY._serialized_end=325
  _BATCHCREATEARTIFACTPARTREQUEST._serialized_start=328
  _BATCHCREATEARTIFACTPARTREQUEST._serialized_end=557
  _BATCHCREATEARTIFACTPARTREQUEST_CONFIGSBYARTIFACTIDENTRY._serialized_start=462
  _BATCHCREATEARTIFACTPARTREQUEST_CONFIGSBYARTIFACTIDENTRY._serialized_end=557
  _CREATEARTIFACTPARTRESULTMETADATA._serialized_start=559
  _CREATEARTIFACTPARTRESULTMETADATA._serialized_end=647
  _CREATEARTIFACTPARTRESULT._serialized_start=650
  _CREATEARTIFACTPARTRESULT._serialized_end=881
  _CREATEARTIFACTPARTRESULT_METADATASBYPARTNUMBERENTRY._serialized_start=776
  _CREATEARTIFACTPARTRESULT_METADATASBYPARTNUMBERENTRY._serialized_end=881
  _BATCHCREATEARTIFACTPARTRESPONSE._serialized_start=884
  _BATCHCREATEARTIFACTPARTRESPONSE._serialized_end=1115
  _BATCHCREATEARTIFACTPARTRESPONSE_RESULTSBYARTIFACTIDENTRY._serialized_start=1020
  _BATCHCREATEARTIFACTPARTRESPONSE_RESULTSBYARTIFACTIDENTRY._serialized_end=1115
# @@protoc_insertion_point(module_scope)
